package ru.kgsu.it;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

public class Utils {

    static final int ADD_USER = 1;
    static final int REMOVE_USER = 2;
    static final int UPDATE_USER = 3;
    static final int PRINT_USERS = 4;

    static final String URL_CONNECTION_DATABASE = "jdbc:postgresql://localhost:5432/usersdb";
    static final String USER_KEY_PROPERTY = "user";
    static final String USER = "sergey";
    static final String PASSWORD_KEY_PROPERTY = "password";
    static final String PASSWORD = "1";

    private static final String CHECK_USER_SQL = "select * from Users where login = ?";
    static final String SELECT_USER_SQL = "select * from Users";
    static final String INSERT_USER_SQL = "insert into Users(login, name, surname) values(?, ?, ?)";
    static final String DELETE_USER_SQL = "delete from Users where login = ?";
    static final String UPDATE_USER_SQL = "update Users set name = ?, surname = ? where login = ?";

    private static BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(System.in));

    /**
     * Функция для вывода меню
     */
    static void printMenu() {
        System.out.println("1) Добавление пользователя");
        System.out.println("2) Удаление пользователя");
        System.out.println("3) Редактирование пользователя");
        System.out.println("4) Вывод списка пользователей");
        System.out.println("5) Выход");
    }

    /**
     * Функция для вывода разделителя строк
     *
     * @param blankLineBeforeSeparator Печатать ли пустую строку перед разделителем
     * @param blankLineAfterSeparator  Печатать ли пустую строку после разделителя
     */
    static void printSeparator(boolean blankLineBeforeSeparator, boolean blankLineAfterSeparator) {
        if (blankLineBeforeSeparator) {
            System.out.println();
        }

        for (int i = 0; i < 70; i++) {
            System.out.print('-');
        }
        System.out.println();

        if (blankLineAfterSeparator) {
            System.out.println();
        }
    }

    /**
     * Функция для чтения строки. Чтение будет продолжаться до тех пор, пока не будет введена не пустая строка.
     *
     * @param hint Строка, которая будет печататься перед каждой попыткой ввода
     * @return Введенная строка
     */
    static String readString(String hint) throws IOException {
        String string = "";
        while (string.isEmpty()) {
            System.out.print(hint);
            string = bufferedReader.readLine();
        }
        return string;
    }

    /**
     * Функция для чтения числа. Чтение будет продолжаться до тех пор, пока не будет введено число.
     *
     * @param hint Строка, которая будет печататься перед каждой попыткой ввода
     * @return Введенное число
     */
    static int readNumber(String hint) throws IOException {
        String string = readString(hint);
        return Integer.parseInt(string);
    }

    /**
     * Функция для проверки наличия пользователя в базе
     *
     * @param conn  Соединение с базой
     * @param login Логин пользователя. Логин пользователя уникален в таблице.
     * @return true, если заданный пользователь есть в базе, false - в противном случае
     */
    static boolean checkUser(Connection conn, String login) throws SQLException {
        PreparedStatement statement = conn.prepareStatement(CHECK_USER_SQL);
        statement.setString(1, login);

        ResultSet rs = statement.executeQuery();
        return rs.next();
    }
}
